T.I.M VFX

PIPELINE_TD // VFX_ENGINEER

Bridging the gap between artistic vision and maximum scalability. From high-end feature films to procedural game environments, I specialize in automating perfection.

STATUS: [AVAILABLE_FOR_DEPLOYMENT]

[SYSTEM_T.I.M_OVERVIEW]

This platform serves as a high-fidelity archival nexus and live development tracker. It is designed to document the intersection of high-end VFX pipeline architecture, real-time proceduralism in Unreal Engine 5, and the emerging field of Agentic AI in technical production.

ACTIVE_PROJECT_STATUS

PROJECT_01: VFX PIPE

Autonomous DCC orchestration layer for high-volume VFX production. Decentralizing dependency management and render-farm synchronization.

PROJECT_02: THE_LAST_BARGE

Physically-based simulation of marine buoyancy and abyssal logistics in Unreal Engine 5. Focus on modular hull integrity and agent-driven traversal.

PROJECT_03: NBODY_SOLVER

GPU-accelerated particle solver utilizing CUDA-LBVH for large-scale astrophysical simulations and real-time VFX particle dynamics.

PROJECT_04: ENTROPY_PROPHET

A decentralized game mechanic for Smart Assemblies within Eve Frontier, the upcoming MMORPG by CCP Games.

SERVICES // EXPERTISE

End-to-end technical solutions designed to scale production output and eliminate workflow friction.

PIPELINE_ARCHITECTURE

Designing and implementing studio-wide production pipelines from scratch. Leveraging Python, C++, and microservice frameworks to replace fragile scripts with robust, database-driven tracking systems.


Capable of integrating Autodesk Maya, Houdini, Nuke, and Unreal Engine into a unified data flow utilizing ShotGrid or custom tracking backends.

Systems Design Automation Flow Process Data Schema

TOOL_DEVELOPMENT

Custom application and tool creation for artists and technical directors. From high-performance C++ plugins to responsive PySide/PyQt artist interfaces embedded directly within DCCs.

PyQt/PySide Agentic AI UX/UI

UNREAL_ENGINE_TECHNICAL_ART

Bridging the gap between offline rendering and real-time. Extensive experience profiling, optimizing, and building procedural generation tools (PCG) within Unreal Engine 5.

Blueprints C++ PCG Framework Niagara

PROCEDURAL_ENV_DESIGN

From deep-sea basins to infinite asteroids. We build procedural generators that output production-ready environment assets in Unreal Engine 5.

UE5 PCG HOUDINI_ENGINE

VFX_TRAINING_&_TECHNICAL_AUDIT

Specializing in large-scale simulations and data management. We provide deep-dive Houdini scene audits to optimize bottlenecks and refine complex simulation setups for production efficiency.

HOUDINI_AUDIT SIM_OPTIMIZATION DATA_DRIVEN_FX

PIPELINE_ARCHITECTURE

DB-DRIVEN ASSET TRACKING AND DCC CONTEXT INJECTION

Fully automated, strictly enforced relational schema serving as the authoritative truth for all asset states. By abstracting the file system entirely, we maintain 100% data integrity across all DCCs. Trust in the schema.

DB_CORE // SQLALCHEMY

The DB Core utilizes SQLite for local caching and syncs continuously with Shotgrid/PostgreSQL. It automatically builds dependency graphs on publish, ensuring that assets sent to the render farm never fail due to missing dependencies or broken referenced paths.

class Publish(Base): __tablename__ = "publishes" id = Column(Integer, primary_key=True) shot_code = Column(String) file_hash = Column(String) # Automated Dependency Resolution dependencies = relationship( "Dependency", back_populates="publish" )
Asset Loader FIG A. Relational dependency mapping and shot-based asset resolution.

ENV_LAUNCH // ISOLATION

A completely stateless DCC operating environment. Shot Launcher resolves the active database context before any software executable runs.


This wrapper injects specific environment variables (OCIO, PYTHONPATH, LICENSE_SERVERS) at runtime based on the shot requirement. No pollution of local OS variables. Every artist boots into a perfectly replicated, sterile environment ensuring exact reproducibility across global studios.

> Auth Token: VALIDATED > Resolving Context: sq010_sh005 > Fetching Environment... > Injecting: HIP_ROOT=/mnt/prj > Bootstrapping DCC... > Launching: houdini-bin (OK)
PIPE Launcher FIG B. Unified environment launcher & context-aware software manifest.

USD_STRUCT // SOLARIS

Procedural, non-destructive, and infinitely modular asset assembly pipeline built completely on Universal Scene Description (USD).


Takes advantage of Houdini Solaris to compose sparse layouts and override materials seamlessly at the sequence and shot levels. We auto-generate proxy, render, and collision variants during publish, allowing Unreal Engine 5 to dynamically load the appropriate payload across sprawling open worlds without stalling the main thread.

Pipe Browser FIG C. Multi-threaded version browser with integrated metadata and playback.

The primary architecture focuses on decentralizing the traditional VFX pipeline. By replacing hardcoded file paths with a relational asset-tracking system, Nexus ensures cross-DCC compatibility (Houdini, Maya, Unreal) without path breakage.

Daily Manager FIG D. Automated daily management and editorial synchronization tools.
Nexus Architecture DIAGRAM 1. Decentralized Asset Orchestration Architecture.

THE LAST BARGE

SURVIVAL BUILDER MEETS NARRATIVE ADVENTURE (UE5)

Imagine a world where the oceans have swallowed civilisation, leaving only the scattered remnants of humanity clinging to floating scraps of the old world. The Last Barge is not just another survival game; it is an exploration of isolation, adaptation, and the terrifying beauty of the deep unknown. We are building an experience that forces players to transition from the cozy, sunlit 'Surface Dream' of Act 1 into a descent towards deep-sea alien horror by Act 4.

At its core, it is about connection. You do not simply craft a raft—you engineer a modular, floating village. Galleys, greenhouses, and moonpools must be interconnected dynamically to survive the relentless atmospheric pressure and procedural anomalies. The ocean itself is a character, reacting and mutating based on real-world USGS bathymetry data fed through a procedural Houdini pipeline.

This is a narrative adventure where the environment dictates the story. With advanced echolocation mechanics replacing traditional vision in the abyssal zones, your scanner becomes your only lifeline. You are not just fighting to survive; you are diving into the abyss to uncover why the waters rose, what lurks beneath, and ultimately decide the fate of whatever is left of humanity.

INITIAL CONCEPTS

HIGH CONCEPT

Hybrid Cozy Village Builder + Exploration/Survival + Narrative Mystery.

CORE PILLARS

Village Management (Surface), Exploration (Underwater), and Narrative Mystery.

NARRATIVE THEMES

Utopia vs. Dystopia, Ignorance vs. Knowledge, and Curiosity.

KEY FACTIONS

The Barter Guild, The Keepers, The Drifters, and The Exiles.

PROGRESSION OUTLINE

Early Game (Survival) to Endgame (Final choice).

Barge Modularity Simulation FIG A. Modular hull buoyancy & physics integration.

AGENTIC AI DEVELOPMENT

Redefining the indie production pipeline.

The development of The Last Barge represents a paradigm shift in how we approach game architecture. Instead of relying solely on traditional manual coding and monolithic blueprints, we are pioneering an Agentic AI-based development stage.

By leveraging autonomous AI agents orchestrated through strict pipeline schemas, we are fundamentally compounding our output. Agents handle the generation of boilerplate C++ classes, procedural asset tagging, and automated regression testing across the Unreal Engine environment.

Agentic Node Topology FIG B. Agentic Node Topology & System Hierarchy.

This isn't just code assistance—this is a collaborative hive-mind. AI agents simulate thousands of physics iterations to balance barge buoyancy, while simultaneously iterating on logic trees for ambient AI behaviors. The result is a AAA-scale procedural world, architected at the speed of thought.

Deep Sea Simulation FIG C. Procedural abyssal ecosystem & lighting.

THE CORE LOOP

  • GATHER SURFACE DEBRIS
  • BUILD MODULAR BARGES
  • DIVE FOR RELICS
  • UPGRADE TECH
  • REVEAL THE TRUTH

NBODY_SOLVER WITH AGENTICAI

CUDA-ACCELERATED N-BODY SIMULATION ENGINE

A high-performance, CUDA-accelerated N-Body simulation engine featuring Barnes-Hut optimization, high-fidelity turbulence (Flow Noise), and native USD export for VFX pipelines. Developed to handle massive scale galactic simulations and turbulent "boiling" spheres inside Houdini/Solaris.

ENGINE ARCHITECTURE

DUAL PHYSICS SOLVERS

Direct Summation (O(N²)) via shared-memory tiled kernels for maximum precision, and Barnes-Hut (O(N log N)) using Linear Bounding Volume Hierarchy (LBVH) traversal.

DYNAMIC FLOW TURBULENCE

Persistent, hash-based clumpy noise patterns with organic motion.

N-Body Simulation Alpha FIG 1. GALAXY_CORE_ALPHA // INITIAL STATE

SIMULATION VISUALS

Real-time cinematic solvers utilizing CUDA for massive-scale gravitational dynamics.

Barnes Hut Galaxy Collision
FILE: BARNES_HUT_GALAXY_COLLISION.GIF // SOLVED_POINTS: 1.2M // 4FPS_OPT

VFX-READY USD EXPORT

Direct `.usdc` binary export with per-frame background threading for real-time Houdini syncing.

CODE INJECTION

The LBVH kernel utilizes shared memory arrays to optimize warp divergence during parallel tree traversal.

__global__ void
calculateForces(float4* p, float3* v) {
  int i = blockIdx.x * blockDim.x + threadIdx.x;
  // Shared memory tiling...
  __shared__ float4 shPosition[BLOCK_SIZE];
  // Barnes-Hut Tree Traversal...
}
                  
FIG 2. LBVH Kernel Implementation snippet
N-Body Collision Beta FIG 3. COLLISION_EVENT_BETA // HIGH_DENSITY
> SYS.SOLVER_SHOWCASE_PLAYBACK RES: 4K // SOURCE: YOUTUBE_STREAM

ENTROPY_PROPHET

SMART ASSEMBLY GAME MECHANIC // BY CCP GAMES

Eve Frontier Logo

REFINERY // SNIFFER

Prophet establishes a decentralized game mechanic for Smart Assemblies within the Eve Frontier ecosystem—the new upcoming MMORPG from CCP Games.

By deploying SUI contract extensions to the `world::gate`, we enable high-fidelity tracking of ship manifests and regional transit events, turning raw on-chain data into actionable intelligence for survival.

Built specifically for the persistent, survival-based universe of Eve Frontier, the Gate Sniffer tracks every jump event, regional ship manifest, and SSU transfer to predict regional shortages and trade opportunities.

Eve Frontier Key Art FIG. Eve Frontier Regional Intelligence Feed.

FRANCHISE_PROTOCOL // VAULT

A trustless revenue-sharing model (70/30) allowing players to host Prophet logic on their own Smart Assemblies.


Utilizing the `eve_vault` for automated fuel distribution and credential-based access control. This decentralized model ensures that the intelligence network scales horizontally across entire constellations.

Exclave Frigate FIG. Automated Frigate Manifest Tracking.
[REVENUE_SPLIT: 70% HOST / 30% PROTOCOL]

PROPHECY_CORE // AI

Natural language threat assessments and AI-driven market forecasting.


The AI Prophecy Core provides off-chain LLM-driven advisors that analyze on-chain traffic data to provide clear, actionable intelligence. It works in tandem with the Thermal Heat Mapper to navigate high-thermal "deviance" zones safely.

Fabricator Model FIG. Smart Assembly Logic Execution.
  • > SUI MOVE CONTRACTS
  • > WORLD GATE AUTH
  • > SUI SEAL PATHFINDING

03 // MEDIA_ARCHIVE

Decoded transmission sequences.

> SYS.PLAYBACK_ENGAGED RES: 4K // FPS: 60

STUDIO ORIENTED // TRAINING

A collection of technical breakdowns, masterclasses, and workflow tutorials. Discover courses covering Unreal Engine, Houdini, and advanced pipeline development.

SUBSCRIBE ON YOUTUBE

HOUDINI & VFX DESTRUCTION

SIMULATIONS & ENVIRONMENTS

06 // DEV_LOG

Operational updates, methodology breakdowns, and pipeline research.

LATEST TRANSMISSION

ARCHIVED LOGS

Data Stream
SYS.LOG_ACTIVE

05 // FILMOGRAPHY

Cinematic visual archive and project credits.

Alien: Earth
Alien: Earth (2025)
Mufasa: The Lion King
Mufasa: The Lion King (2024)
Halo
Halo TV Series (2022)
Wednesday
Wednesday (2022)
Godzilla vs. Kong
Godzilla vs. Kong (2021)
The Suicide Squad
The Suicide Squad (2021)
Aquaman
Aquaman (2018)
Ghost in the Shell
Ghost in the Shell (2017)
X-Men: Apocalypse
X-Men: Apocalypse (2016)
Dark Phoenix
X-Men: Dark Phoenix (2019)
Artemis Fowl
Artemis Fowl (2020)
The Mummy
The Mummy (2017)
Goosebumps
Goosebumps (2015)
The Expendables 3
The Expendables 3 (2014)
Resident Evil
Resident Evil: WTRC (2021)
Where the Crawdads Sing
Where the Crawdads Sing (2022)

07 // IDENTITY // TIMUCIN OZGER

With over 15 years in high-end feature film production, I specialize in bridging the gap between artistic vision and technical scalability.


Having served as Head of CG and CG Supervisor at studios like MPC and Mr. X, I lead teams to deliver world-class VFX for projects like Godzilla vs Kong, Aquaman, and Justice League.

CONTACT // QUERIES

tricecold@gmail.com
ACCESS_GRANTED // IDENTITY_VERIFIED

CORE_EXPERTISE

  • SideFX Houdini
  • UNREAL ENGINE 5
  • Autodesk MAYA
  • PYTHON
  • USD
  • Automation
  • Visual Effects
  • Flow Design
Timucin Ozger // Bio